==> haskell-deferred-folds-0.9.10.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-deferred-folds.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: deferred-folds
version: 0.9.10.1
id: deferred-folds-0.9.10.1-KL6n3HrYX8PEpspHZGTB8r
key: deferred-folds-0.9.10.1-KL6n3HrYX8PEpspHZGTB8r
license: MIT
copyright: (c) 2018, Metrix.AI
maintainer: Metrix.AI Tech Team <tech@metrix.ai>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
stability: Experimental
homepage: https://github.com/metrix-ai/deferred-folds
synopsis: Abstractions over deferred folds
description:
    This library is in an experimental state.
    Users should be prepared for frequent updates.
category: Folding
abi: 4a2394c4f2a68295dada866ccd697599
exposed: True
exposed-modules:
    DeferredFolds.Unfoldl DeferredFolds.UnfoldlM DeferredFolds.Unfoldr
hidden-modules: DeferredFolds.Types DeferredFolds.UnfoldrM
                DeferredFolds.Defs.Unfoldl DeferredFolds.Defs.UnfoldlM
                DeferredFolds.Defs.Unfoldr DeferredFolds.Defs.UnfoldrM
                DeferredFolds.Prelude
import-dirs: /usr/lib/ghc-8.6.5/site-local/deferred-folds-0.9.10.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/deferred-folds-0.9.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/deferred-folds-0.9.10.1
hs-libraries: HSdeferred-folds-0.9.10.1-KL6n3HrYX8PEpspHZGTB8r
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    foldl-1.4.5-GQ9JqYILkJv1VZDndE8el4
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b transformers-0.5.6.2
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-deferred-folds/html/deferred-folds.haddock
haddock-html: /usr/share/doc/haskell-deferred-folds/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deferred-folds-0.9.10.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-deferred-folds.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: deferred-folds
version: 0.9.10.1
id: deferred-folds-0.9.10.1-FIm7PQcMGTGKYji2M0KpEw
key: deferred-folds-0.9.10.1-FIm7PQcMGTGKYji2M0KpEw
license: MIT
copyright: (c) 2018, Metrix.AI
maintainer: Metrix.AI Tech Team <tech@metrix.ai>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
stability: Experimental
homepage: https://github.com/metrix-ai/deferred-folds
synopsis: Abstractions over deferred folds
description:
    This library is in an experimental state.
    Users should be prepared for frequent updates.
category: Folding
abi: e99e5ce074e2b934031355370b392a6e
exposed: True
exposed-modules:
    DeferredFolds.Unfoldl DeferredFolds.UnfoldlM DeferredFolds.Unfoldr
hidden-modules: DeferredFolds.Types DeferredFolds.UnfoldrM
                DeferredFolds.Defs.Unfoldl DeferredFolds.Defs.UnfoldlM
                DeferredFolds.Defs.Unfoldr DeferredFolds.Defs.UnfoldrM
                DeferredFolds.Prelude
import-dirs: /usr/lib/ghc-8.6.5/site-local/deferred-folds-0.9.10.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/deferred-folds-0.9.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/deferred-folds-0.9.10.1
hs-libraries: HSdeferred-folds-0.9.10.1-FIm7PQcMGTGKYji2M0KpEw
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    foldl-1.4.5-GQ9JqYILkJv1VZDndE8el4
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b transformers-0.5.6.2
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-deferred-folds/html/deferred-folds.haddock
haddock-html: /usr/share/doc/haskell-deferred-folds/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
